<?xml version="1.0" encoding="UTF-8"?>
<!--
	XSLT for transforming NewsCodes provided as an IPTC G2 Knowledge Item into a RDF/XML+SKOS instance.
	(c) 2012, IPTC - www.iptc.org
	See license for using this file at: http://www.iptc.org/goto?license
	Author: Michael Steidl, IPTC
	Version:
	v3: 2011-03-28
	v4: 2012-09-19: mapping of Schema Aliases to Scheme URIs added, skos:hasTopConcept simplified (rdf:resource replaces a full rdf:Description)
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://iptc.org/std/nar/2006-10-01/" xmlns:nar="http://iptc.org/std/nar/2006-10-01/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:skos="http://www.w3.org/2004/02/skos/core#" xmlns:owl="http://www.w3.org/2002/07/owl#">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:variable name="schemeURI"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(//nar:concept[1]/nar:conceptId/@qcode,':')"/></xsl:call-template></xsl:variable>
	<xsl:template match="/">
		<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:skos="http://www.w3.org/2004/02/skos/core#">
			<xsl:apply-templates select="//nar:conceptSet" mode="SchemeList"/>
			<xsl:apply-templates select="//nar:conceptSet" mode="Concepts"/>
		</rdf:RDF>
	</xsl:template>
	<!-- ********* Template to create the SKOS Concept Scheme class -->
	<xsl:template match="nar:conceptSet" mode="SchemeList">
		<rdf:Description>
			<xsl:attribute name="rdf:about"><xsl:value-of select="$schemeURI"/></xsl:attribute>
			<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#ConceptScheme"/>
			<!-- the selection below builds on the style of IPTC-delivered KIs to provide broader elements for all children in a taxonomy tree
					Thus the concepts with no broader elements are the concepts at the top level -->
			<xsl:for-each select="nar:concept[count(nar:broader) = 0]">
				<skos:hasTopConcept>
						<xsl:attribute name="rdf:resource"><xsl:value-of select="$schemeURI"/><xsl:value-of select="substring-after(nar:conceptId/@qcode,':')"></xsl:value-of></xsl:attribute>
				</skos:hasTopConcept>
			</xsl:for-each>
		</rdf:Description>
	</xsl:template>
	<!-- ********* Template to create individual SKOS Concept classes -->
	<xsl:template match="nar:conceptSet" mode="Concepts">
		<xsl:for-each select="nar:concept">
			<rdf:Description>
				<xsl:attribute name="rdf:about"><xsl:value-of select="$schemeURI"/><xsl:value-of select="substring-after(nar:conceptId/@qcode,':')"/></xsl:attribute>
				<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
				<xsl:for-each select="nar:name">
					<skos:prefLabel>
						<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
						<xsl:value-of select="."/>
					</skos:prefLabel>
				</xsl:for-each>
				<xsl:for-each select="nar:definition">
					<skos:definition>
						<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
						<xsl:value-of select="."/>
					</skos:definition>
				</xsl:for-each>
				<skos:inScheme>
					<xsl:attribute name="rdf:resource"><xsl:value-of select="$schemeURI"/></xsl:attribute>
				</skos:inScheme>
				<!-- create broader relationships: they exist as broader elements in the IPTC-delivered KIs -->
				<xsl:comment>Broader Relationships</xsl:comment>
				<xsl:for-each select="nar:broader">
					<skos:broaderTransitive>
						<rdf:Description>
							<xsl:attribute name="rdf:about"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
							<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
						</rdf:Description>
					</skos:broaderTransitive>
				</xsl:for-each>
				<!-- create narrower relationships: inverted selection: narrower concepts are concepts with a broader element referring to "this" concept -->
				<xsl:comment>Narrower Relationships</xsl:comment>
				<xsl:variable name="thisQCode"><xsl:value-of select="./nar:conceptId/@qcode" /></xsl:variable>
				<xsl:for-each select="../nar:concept[nar:broader/@qcode=$thisQCode]">
					<skos:narrower>
						<rdf:Description>
							<xsl:attribute name="rdf:about"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(nar:conceptId/@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(nar:conceptId/@qcode,':')"/></xsl:attribute>
							<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
						</rdf:Description>
					</skos:narrower>
				</xsl:for-each>
				<!-- create SKOS mapping relationships -->
				<xsl:comment>SKOS Mapping Relationships</xsl:comment>
				<xsl:for-each select="nar:related">
					<xsl:choose>
						<xsl:when test="@rel='skos:exactMatch' ">
						<skos:exactMatch>
						<xsl:attribute name="rdf:resource"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:exactMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:closeMatch' ">
						<skos:closeMatch>
						<xsl:attribute name="rdf:resource"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:closeMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:broadMatch' ">
						<skos:broadMatch>
						<xsl:attribute name="rdf:resource"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:broadMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:narrowMatch' ">
						<skos:narrowMatch>
						<xsl:attribute name="rdf:resource"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:narrowMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:releatedMatch' ">
						<skos:relatedMatch>
						<xsl:attribute name="rdf:resource"><xsl:call-template name="schemaAliasToURI"><xsl:with-param name="schemeAlias" select="substring-before(@qcode,':')"/></xsl:call-template><xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:relatedMatch>
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>
			</rdf:Description>
		</xsl:for-each>
	</xsl:template>
	<!-- ********* Template to write the URL corresponding to a QCode Scheme Alias -->
<!--	This template covers all scheme entries from the IPTC catalog which can be found at
	http://www.iptc.org/std/catalog/catalog.IPTC-G2-Standards_19.xml
-->	
	<xsl:template name="schemaAliasToURI">
		<xsl:param name="schemeAlias"/>
		<xsl:choose>
			<xsl:when test="$schemeAlias = '' ">http://cv.iptc.org/newscodes/ALIAS-WAS-BLANK/</xsl:when>
			<xsl:when test="$schemeAlias = 'dummy'">http://cv.iptc.org/newscodes/dummy/</xsl:when>
			<xsl:when test="$schemeAlias = 'acdc'">http://cv.iptc.org/newscodes/audiocodec/</xsl:when>
			<xsl:when test="$schemeAlias = 'genre'">http://cv.iptc.org/newscodes/genre/</xsl:when>
			<xsl:when test="$schemeAlias = 'medtop'">http://cv.iptc.org/newscodes/mediatopic/</xsl:when>
			<xsl:when test="$schemeAlias = 'prov'">http://cv.iptc.org/newscodes/provider/</xsl:when>
			<xsl:when test="$schemeAlias = 'nprov'">http://cv.iptc.org/newscodes/newsprovider/</xsl:when>
			<xsl:when test="$schemeAlias = 'nprod'">http://cv.iptc.org/newscodes/newsproduct/</xsl:when>
			<xsl:when test="$schemeAlias = 'scn'">http://cv.iptc.org/newscodes/scene/</xsl:when>
			<xsl:when test="$schemeAlias = 'subj'">http://cv.iptc.org/newscodes/subjectcode/</xsl:when>
			<xsl:when test="$schemeAlias = 'squ'">http://cv.iptc.org/newscodes/subjectqualifier/</xsl:when>
			<xsl:when test="$schemeAlias = 'vcdc'">http://cv.iptc.org/newscodes/videocodec/</xsl:when>
			<xsl:when test="$schemeAlias = 'wldreg'">http://cv.iptc.org/newscodes/worldregion/</xsl:when>
			<xsl:when test="$schemeAlias = 'digsrctype'">http://cv.iptc.org/newscodes/digitalsourcetype/</xsl:when>
			<xsl:when test="$schemeAlias = 'ninat'">http://cv.iptc.org/newscodes/ninature/</xsl:when>
			<xsl:when test="$schemeAlias = 'cinat'">http://cv.iptc.org/newscodes/cinature/</xsl:when>
			<xsl:when test="$schemeAlias = 'plinat'">http://cv.iptc.org/newscodes/plinature/</xsl:when>
			<xsl:when test="$schemeAlias = 'cpnat'">http://cv.iptc.org/newscodes/cpnature/</xsl:when>
			<xsl:when test="$schemeAlias = 'crel'">http://cv.iptc.org/newscodes/conceptrelation/</xsl:when>
			<xsl:when test="$schemeAlias = 'mtyp'">http://cv.iptc.org/newscodes/mediatype/</xsl:when>
			<xsl:when test="$schemeAlias = 'drol'">http://cv.iptc.org/newscodes/descriptionrole/</xsl:when>
			<xsl:when test="$schemeAlias = 'erol'">http://cv.iptc.org/newscodes/edrole/</xsl:when>
			<xsl:when test="$schemeAlias = 'irel'">http://cv.iptc.org/newscodes/itemrelation/</xsl:when>
			<xsl:when test="$schemeAlias = 'irep'">http://cv.iptc.org/newscodes/itemrepresentation/</xsl:when>
			<xsl:when test="$schemeAlias = 'pgrmod'">http://cv.iptc.org/newscodes/pkggroupmode/</xsl:when>
			<xsl:when test="$schemeAlias = 'stat'">http://cv.iptc.org/newscodes/pubstatusg2/</xsl:when>
			<xsl:when test="$schemeAlias = 'rnd'">http://cv.iptc.org/newscodes/rendition/</xsl:when>
			<xsl:when test="$schemeAlias = 'nrol'">http://cv.iptc.org/newscodes/namerole/</xsl:when>
			<xsl:when test="$schemeAlias = 'nprt'">http://cv.iptc.org/newscodes/namepart/</xsl:when>
			<xsl:when test="$schemeAlias = 'why'">http://cv.iptc.org/newscodes/whypresent/</xsl:when>
			<xsl:when test="$schemeAlias = 'isrol'">http://cv.iptc.org/newscodes/infosourcerole/</xsl:when>
			<xsl:when test="$schemeAlias = 'lrol'">http://cv.iptc.org/newscodes/languagerole/</xsl:when>
			<xsl:when test="$schemeAlias = 'ciprol'">http://cv.iptc.org/newscodes/contactinfopartrole/</xsl:when>
			<xsl:when test="$schemeAlias = 'ctech'">http://cv.iptc.org/newscodes/commtech/</xsl:when>
			<xsl:when test="$schemeAlias = 'cwarn'">http://cv.iptc.org/newscodes/contentwarning/</xsl:when>
			<xsl:when test="$schemeAlias = 'sig'">http://cv.iptc.org/newscodes/signal/</xsl:when>
			<xsl:when test="$schemeAlias = 'app'">http://cv.iptc.org/newscodes/application/</xsl:when>
			<xsl:when test="$schemeAlias = 'riaspect'">http://cv.iptc.org/newscodes/riaspect/</xsl:when>
			<xsl:when test="$schemeAlias = 'riscope'">http://cv.iptc.org/newscodes/riscope/</xsl:when>
			<xsl:when test="$schemeAlias = 'hopaction'">http://cv.iptc.org/newscodes/hopaction/</xsl:when>
			<xsl:when test="$schemeAlias = 'hatarget'">http://cv.iptc.org/newscodes/hopactiontarget/</xsl:when>
			<xsl:when test="$schemeAlias = 'hashtype'">http://cv.iptc.org/newscodes/hashtype/</xsl:when>
			<xsl:when test="$schemeAlias = 'hashscope'">http://cv.iptc.org/newscodes/hashscope/</xsl:when>
			<xsl:when test="$schemeAlias = 'sov'">http://cv.iptc.org/newscodes/videoscaling/</xsl:when>
			<xsl:when test="$schemeAlias = 'colin'">http://cv.iptc.org/newscodes/colourindicator/</xsl:when>
			<xsl:when test="$schemeAlias = 'videodef'">http://cv.iptc.org/newscodes/videodefinition/</xsl:when>
			<xsl:when test="$schemeAlias = 'sev'">http://cv.iptc.org/newscodes/severity/</xsl:when>
			<xsl:when test="$schemeAlias = 'howextr'">http://cv.iptc.org/newscodes/howextracted/</xsl:when>
			<xsl:when test="$schemeAlias = 'nmsig'">http://cv.iptc.org/newscodes/newsmsgsignal/</xsl:when>
			<xsl:when test="$schemeAlias = 'timeunit'">http://cv.iptc.org/newscodes/timeunit/</xsl:when>
			<xsl:when test="$schemeAlias = 'dimensionunit'">http://cv.iptc.org/newscodes/dimensionunit/</xsl:when>
			<xsl:when test="$schemeAlias = 'edconf'">http://cv.iptc.org/newscodes/eventdateconfirm/</xsl:when>
			<xsl:when test="$schemeAlias = 'eocstat'">http://cv.iptc.org/newscodes/eventoccurstatus/</xsl:when>
			<xsl:when test="$schemeAlias = 'eregrol'">http://cv.iptc.org/newscodes/eventregrole/</xsl:when>
			<xsl:when test="$schemeAlias = 'eprol'">http://cv.iptc.org/newscodes/eventparticipantrole/</xsl:when>
			<xsl:when test="$schemeAlias = 'eorol'">http://cv.iptc.org/newscodes/eventorganiserrole/</xsl:when>
			<xsl:when test="$schemeAlias = 'ecirol'">http://cv.iptc.org/newscodes/eventcontactinforole/</xsl:when>
			<xsl:when test="$schemeAlias = 'ncostat'">http://cv.iptc.org/newscodes/newscoveragestatus/</xsl:when>
			<xsl:when test="$schemeAlias = 'chprop'">http://cv.iptc.org/newscodes/characteristicsproperty/</xsl:when>
			<xsl:when test="$schemeAlias = 'colsp'">http://cv.iptc.org/newscodes/colorspace/</xsl:when>
			<xsl:when test="$schemeAlias = 'conf'">http://cv.iptc.org/newscodes/confidence/</xsl:when>
			<xsl:when test="$schemeAlias = 'encd'">http://cv.iptc.org/newscodes/encoding/</xsl:when>
			<xsl:when test="$schemeAlias = 'frmt'">http://cv.iptc.org/newscodes/format/</xsl:when>
			<xsl:when test="$schemeAlias = 'howpr'">http://cv.iptc.org/newscodes/howpresent/</xsl:when>
			<xsl:when test="$schemeAlias = 'impt'">http://cv.iptc.org/newscodes/importance/</xsl:when>
			<xsl:when test="$schemeAlias = 'lbtyp'">http://cv.iptc.org/newscodes/labeltype/</xsl:when>
			<xsl:when test="$schemeAlias = 'loctyp'">http://cv.iptc.org/newscodes/location/</xsl:when>
			<xsl:when test="$schemeAlias = 'medtyp'">http://cv.iptc.org/newscodes/mediatype1/</xsl:when>
			<xsl:when test="$schemeAlias = 'nityp'">http://cv.iptc.org/newscodes/newsitemtype/</xsl:when>
			<xsl:when test="$schemeAlias = 'not'">http://cv.iptc.org/newscodes/notation/</xsl:when>
			<xsl:when test="$schemeAlias = 'oito'">http://cv.iptc.org/newscodes/ofinterestto/</xsl:when>
			<xsl:when test="$schemeAlias = 'prio'">http://cv.iptc.org/newscodes/priority/</xsl:when>
			<xsl:when test="$schemeAlias = 'prop'">http://cv.iptc.org/newscodes/property/</xsl:when>
			<xsl:when test="$schemeAlias = 'rel'">http://cv.iptc.org/newscodes/relevance/</xsl:when>
			<xsl:when test="$schemeAlias = 'role1'">http://cv.iptc.org/newscodes/role1/</xsl:when>
			<xsl:when test="$schemeAlias = 'pst1'">http://cv.iptc.org/newscodes/status1/</xsl:when>
			<xsl:when test="$schemeAlias = 'tpctyp'">http://cv.iptc.org/newscodes/topictype/</xsl:when>
			<xsl:when test="$schemeAlias = 'urgy'">http://cv.iptc.org/newscodes/urgency/</xsl:when>
			<xsl:when test="$schemeAlias = 'a1312cat'">http://cvx.iptc.org/anpa1312-category/</xsl:when>
			<xsl:when test="$schemeAlias = 'a1312prio'">http://cvx.iptc.org/anpa1312-priority/</xsl:when>
			<xsl:when test="$schemeAlias = 'a1312svc'">http://cvx.iptc.org/anpa1312-servicelevel/</xsl:when>
			<xsl:when test="$schemeAlias = 'a1312vers'">http://cvx.iptc.org/anpa1312-version/</xsl:when>
			<xsl:when test="$schemeAlias = 'isin'">http://cvx.iptc.org/isin/</xsl:when>
			<xsl:when test="$schemeAlias = 'iso3166-1a2'">http://cvx.iptc.org/iso3166-1a2/</xsl:when>
			<xsl:when test="$schemeAlias = 'iso3166-1a3'">http://cvx.iptc.org/iso3166-1a3/</xsl:when>
			<xsl:when test="$schemeAlias = 'iso4217a'">http://cvx.iptc.org/iso4217a/</xsl:when>
			<xsl:when test="$schemeAlias = 'iso4217n'">http://cvx.iptc.org/iso4217n/</xsl:when>
			<xsl:when test="$schemeAlias = 'mic'">http://cvx.iptc.org/iso10383-mic</xsl:when>
			<xsl:when test="$schemeAlias = 'skos'">http://www.w3.org/2004/02/skos/core#</xsl:when>
			<xsl:otherwise>http://cv.iptc.org/newscodes/ALIAS-IS-UNKNOWN/</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
</xsl:stylesheet>
