<?xml version="1.0" encoding="UTF-8"?>
<!--
	XSLT for transforming NewsCodes provided as an IPTC G2 Knowledge Item into a structured CSV

	(c) Copyright 2011, IPTC, www.iptc.org
	See license for using this file at: http://www.iptc.org/goto?license
	File name: IPTC-G2KI-to-treeCSV.xslt
	Author: Michael Steidl
	v2: 2011-03-28
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nar="http://iptc.org/std/nar/2006-10-01/" >
	<xsl:output method="text" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- semi-constants to be used throughout the transform -->
	<xsl:variable name="LineEnd">
		<xsl:text>&#x0D;&#x0A;</xsl:text>
	</xsl:variable>
	<xsl:variable name="ValSep">
		<!-- the character below is the separator of the field values, 
			this character may has to be adjusted to local settings, 
			mainly either a comma or a semicolon -->
		<xsl:text>;</xsl:text>
	</xsl:variable>
	<!-- the variable below may be changed if another sorting order is required -->
	<xsl:variable name="SortSelector" select="'./nar:conceptId/@qcode'" />
	<!-- the MAIN TEMPLATE ************************************************ -->
	<xsl:template match="/">
		<!-- the top row with the field headings -->
		<xsl:text>NewsCode-QCode (flat)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Level 1/NewsCode</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Level 2/NewsCode</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Level 3/NewsCode</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Level 4/NewsCode</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Level 5/NewsCode</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Name (en-GB)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Definition (en-GB)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Name (fr)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Definition (fr)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Name (es)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Definition (es)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Name (de)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Definition (de)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Name (it)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Definition (it)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Name (jp)</xsl:text>
		<xsl:value-of select="$ValSep"/>
		<xsl:text>Definition (jp)</xsl:text>
		<xsl:value-of select="$LineEnd"/>
		<!-- select the top level 1 NewsCodes  -->
		<xsl:apply-templates select="//nar:concept[count(nar:broader) = 0]" mode="recursive">
		<xsl:sort select="$SortSelector"></xsl:sort>
			<xsl:with-param name="LevelPrefix">
				<xsl:value-of select="''"/>
			</xsl:with-param>
			<xsl:with-param name="LevelSuffix">
				<xsl:value-of select="concat($ValSep,$ValSep,$ValSep,$ValSep,$ValSep)"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	<!-- the template for each concept - processed recursively to traverse treelike structures ********************************* -->
	<xsl:template match="nar:concept" mode="recursive">
		<xsl:param name="LevelPrefix"/>
		<xsl:param name="LevelSuffix"/>
		<xsl:value-of select="./nar:conceptId/@qcode"/>
		<xsl:value-of select="$ValSep"/>
		<xsl:value-of select="$LevelPrefix"></xsl:value-of>
		<xsl:value-of select="./nar:conceptId/@qcode"></xsl:value-of>
		<xsl:value-of select="$LevelSuffix"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:name[@xml:lang = 'en-GB']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:definition[@xml:lang = 'en-GB']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:name[@xml:lang = 'fr']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:definition[@xml:lang = 'fr']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:name[@xml:lang = 'es']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:definition[@xml:lang = 'es']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:name[@xml:lang = 'de']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:definition[@xml:lang = 'de']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:name[@xml:lang = 'it']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:definition[@xml:lang = 'it']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:name[@xml:lang = 'ja-JP']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$ValSep"/>	
		<xsl:text>"</xsl:text>
		<xsl:value-of select="./nar:definition[@xml:lang = 'ja-JP']"></xsl:value-of>
		<xsl:text>"</xsl:text>
		<xsl:value-of select="$LineEnd"/>
		<xsl:apply-templates select="//nar:concept[nar:broader/@qcode=current()/nar:conceptId/@qcode]" mode="recursive">
		<xsl:sort select="$SortSelector"></xsl:sort>
			<xsl:with-param name="LevelPrefix">
				<xsl:value-of select="concat($LevelPrefix,$ValSep)"/>
			</xsl:with-param>
			<xsl:with-param name="LevelSuffix">
				<xsl:value-of select="substring($LevelSuffix,2)"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
</xsl:stylesheet>
